% Définition des paramètres pour la simulation de champ gaussien
modele_variogramme = [4, 10, 10, 10, 0, 0, 0];  % Paramètres du modèle de variogramme
plateau = 0.25;                                  % Plateau du modèle
nombre_simulations = 100;                        % Nombre de réalisations
nx = 51; ny = 51; nz = 1;     % Dimensions du champ (nz fixe à 1)

% Création de la grille spatiale
grille_spatiale = grille3(1, nx, 1, 1, ny, 1, 1, nz, 1);

% Définition du nombre d'itérations pour la méthode de déformation graduelle
nombre_iterations_GD = 10;

% Initialisation et calcul des simulations avec la déformation graduelle
tic  % Démarrage du chronomètre
[Zsim, WCsim, WCinit,erreur] = GDOpt(grille_spatiale, modele_variogramme, plateau, nombre_simulations, nombre_iterations_GD);
temps_moyen = toc / nombre_simulations;  % Calcul du temps moyen par simulation

% Enregistrement des résultats
save('Resultats.mat', 'Zsim','WCsim', 'erreur', 'temps_moyen');

% Affichage des résultats
fprintf('Temps moyen par simulation (déformation graduelle) : %.4f secondes\n', temps_moyen);

%% Tracer les courbes pour chaque puits
num_steps = 10;
time_steps = logspace(0, 3, num_steps) * day;  % Pas de temps logarithmique
load modelInit.mat  WCref 

% Boucle sur les 3 puits pour générer une figure distincte
for i = 1:3
    figure(i+100);  % Créer une figure pour chaque puits
    hold on;

    % Tracer la courbe de référence pour chaque puits
    plot(cumsum(time_steps) / day, WCref(:, i), '-o', 'DisplayName', ['Puits ' num2str(i) ' (Référence)']);

    % Tracer les courbes simulées pour chaque puits
    for j = 1:num_steps
        plot(cumsum(time_steps) / day, WCsim(:, i, j), '-', 'Color', [0.8 0.8 0.8], 'HandleVisibility', 'off');  % Simulations en gris pâle
        plot(cumsum(time_steps) / day, WCinit(:, i, j), '-', 'Color', [0.5 0.5 0.5], 'HandleVisibility', 'off');  % Simulations initiales en gris
    end
    
    % Calcul de la moyenne des simulations simulées et initiales
    WCsim_mean = mean(WCsim(:, i, :), 3);
    plot(cumsum(time_steps) / day, WCsim_mean, '-', 'Color', 'k', 'LineWidth', 2, 'DisplayName', ['Puits ' num2str(i) ' (Moyenne Simulée)']);
    WCinit_mean = mean(WCinit(:, i, :), 3);
    plot(cumsum(time_steps) / day, WCinit_mean, '-', 'Color', 'r', 'LineWidth', 2, 'DisplayName', ['Puits ' num2str(i) ' (Moyenne Initiale)']);
    
    hold off;

    % Appliquer l'échelle logarithmique à l'axe X
    set(gca, 'XScale', 'log');  % Échelle logarithmique pour l'axe X
    xlabel('Temps (jours)');
    ylabel('Saturation en eau');
    legend;
    title(['Évolution de la saturation en eau pour le ' 'Puits ' num2str(i)]);
    grid on;

    % Appliquer un ajustement pour ne pas avoir de valeurs infinies ou NaN sur un axe logarithmique
    ax = gca;
    ax.XTick = [1 10 100 1000];  % Définir les ticks de l'axe X
end